package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.system.dto.MissionsDto;
import com.ruoyi.system.dto.MissionsListDto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.MissionsMapper;
import com.ruoyi.system.domain.Missions;
import com.ruoyi.system.service.IMissionsService;

/**
 * 无人机任务Service业务层处理
 *
 * @author ruoyi
 * @date 2024-09-18
 */
@Service
public class MissionsServiceImpl implements IMissionsService {
    @Autowired
    private MissionsMapper missionsMapper;

    /**
     * 查询无人机任务
     *
     * @param id 无人机任务主键
     * @return 无人机任务
     */
    @Override
    public Missions selectMissionsById(Long id) {
        return missionsMapper.selectMissionsById(id);
    }

    /**
     * 查询无人机任务列表
     *
     * @param missions 无人机任务
     * @return 无人机任务
     */
    @Override
    public List<Missions> selectMissionsList(Missions missions) {
        return missionsMapper.selectMissionsList(missions);
    }

    /**
     * 新增无人机任务
     *
     * @param missions 无人机任务
     * @return 结果
     */
    @Override
    public int insertMissions(Missions missions) {
        return missionsMapper.insertMissions(missions);
    }

    /**
     * 修改无人机任务
     *
     * @param missions 无人机任务
     * @return 结果
     */
    @Override
    public int updateMissions(Missions missions) {
        return missionsMapper.updateMissions(missions);
    }

    /**
     * 批量删除无人机任务
     *
     * @param ids 需要删除的无人机任务主键
     * @return 结果
     */
    @Override
    public int deleteMissionsByIds(Long[] ids) {
        return missionsMapper.deleteMissionsByIds(ids);
    }

    @Override
    public MissionsDto getLatest(String gateway) {
        return missionsMapper.getLatest(gateway);
    }

    @Override
    public void updateMissionsByFlightId(Missions missions) {
        missionsMapper.updateMissionsByFlightId(missions);
    }

    @Override
    public List<MissionsDto> list(MissionsListDto missionListDto) {
        return missionsMapper.list(missionListDto);
    }

    /**
     * 删除无人机任务信息
     *
     * @param id 无人机任务主键
     * @return 结果
     */
    @Override
    public int deleteMissionsById(Long id) {
        return missionsMapper.deleteMissionsById(id);
    }
}
